====
Step
====

The Step commands described in this chapter are used to create and configure analysis steps. Step commands (output) describes the commands used to create and configure output requests and integrated output sections and the commands to configure diagnostic printing, monitoring, and restart. Step commands (miscellaneous) describes the commands used to configure controls, damping, and frequency tables.

.. toctree::
   :maxdepth: 1
   :caption: Objects in Step

   step/step_miscellaneous


Create steps
------------

.. autoclass:: abaqus.Step.StepModel.StepModel
    :noindex:

    .. autoclasstoc::

.. This is a comment ro supress the warning "(ERROR/3) Document may not end with a transition."
